UTF-8 (EF BB BF)
# pygrafical (beta)

**pygrafical** - это графическая библиотека основания на  Windows API написаная на С++ созданая для оптимизации графических функций 

## Установка
для установки библиотеки можно использовать  такую команду
```bash
pip install pygrafical
```
## Функции
в этой библиоттеке множество функций
## Чего нового
добавлена функция для получкния пути к хукам